package com.ruoyi.powerdistribution.service;

import java.util.List;
import com.ruoyi.powerdistribution.domain.PdmPar;

/**
 * 配网参数配置Service接口
 * 
 * @author ruoyi
 * @date 2024-12-04
 */
public interface IPdmParService 
{
    /**
     * 查询配网参数配置
     * 
     * @param id 配网参数配置主键
     * @return 配网参数配置
     */
    public PdmPar selectPdmParById(Long id);

    /**
     * 查询配网参数配置列表
     * 
     * @param pdmPar 配网参数配置
     * @return 配网参数配置集合
     */
    public List<PdmPar> selectPdmParList(PdmPar pdmPar);

    /**
     * 新增配网参数配置
     * 
     * @param pdmPar 配网参数配置
     * @return 结果
     */
    public int insertPdmPar(PdmPar pdmPar);

    /**
     * 修改配网参数配置
     * 
     * @param pdmPar 配网参数配置
     * @return 结果
     */
    public int updatePdmPar(PdmPar pdmPar);

    /**
     * 批量删除配网参数配置
     * 
     * @param ids 需要删除的配网参数配置主键集合
     * @return 结果
     */
    public int deletePdmParByIds(Long[] ids);

    /**
     * 删除配网参数配置信息
     * 
     * @param id 配网参数配置主键
     * @return 结果
     */
    public int deletePdmParById(Long id);
}
